@@ -4,6 +4,22 @@ use Moose;
 extends 'Chart::Clicker::Renderer::Base';
 
 has '+additive' => ( default => 1 );
+has 'opacity' => (
+    is => 'rw',
+    isa => 'Num',
+    default => 0
+);
+has 'padding' => (
+    is => 'rw',
+    isa => 'Int',
+    default => 0
+);
+has 'stroke' => (
+    is => 'rw',
+    isa => 'Chart::Clicker::Drawing::Stroke',
+    default => sub { new Chart::Clicker::Drawing::Stroke() }
+);
+
 
 sub prepare {
     my $self = shift();
@@ -40,27 +56,15 @@ sub draw {
     my $height = $self->height();
     my $width = $self->width();
 
-    # my $xper = $domain->per();
-    # my $yper = $range->per();
-
     my @vals = @{ $series->values() };
     my @keys = @{ $series->keys() };
 
     my $color = $clicker->color_allocator->next();
 
-    my $padding = $self->get_option('padding');
-    unless($padding) {
-        $padding = 1;
-    }
+    my $padding = $self->padding();
 
-    my $stroke = $self->get_option('stroke');
-    my $strokewidth;
-    if(defined($stroke)) {
-        $strokewidth = $stroke->width();
-        $padding += $strokewidth;
-    }
-
-    #my $xper = $self->width() / ($self->{'KEYCOUNT'});
+    my $strokewidth = $self->stroke->width();
+    $padding += $strokewidth;
 
     # Calculate the bar width we can use to fit all the datasets.
     if(!$self->{'BWIDTH'}) {
@@ -86,11 +90,10 @@ sub draw {
         $self->{'KEY_HEIGHT'}->{$_} += $y + $strokewidth;
     }
 
-    my $opac = $self->get_option('opacity');
-    my $fillcolor;
-    if($opac) {
+	my $fillcolor;
+    if($self->opacity()) {
         $fillcolor = $color->clone();
-        $fillcolor->alpha($opac);
+        $fillcolor->alpha($self->opacity());
     } else {
         $fillcolor = $color;
     }
@@ -98,14 +101,12 @@ sub draw {
     $cr->set_source_rgba($fillcolor->rgba());
     $cr->fill_preserve();
 
-    if(defined($stroke)) {
-        $cr->set_line_width($stroke->width());
-        $cr->set_line_cap($stroke->line_cap());
-        $cr->set_line_join($stroke->line_join());
+    $cr->set_line_width($self->stroke->width());
+    $cr->set_line_cap($self->stroke->line_cap());
+    $cr->set_line_join($self->stroke->line_join());
 
-        $cr->set_source_rgba($color->rgba());
-        $cr->stroke();
-    }
+    $cr->set_source_rgba($color->rgba());
+    $cr->stroke();
 
     $self->{'SCOUNT'}++;
 
@@ -127,14 +128,10 @@ Chart::Clicker::Renderer::StackedBar renders a dataset as stacked bars.
 
   my $br = new Chart::Clicker::Renderer::Bar({});
 
-=head1 OPTIONS
+=head1 ATTRIBUTES
 
 =over 4
 
-=item stroke
-
-A stroke to use on each bar.
-
 =item opacity
 
 If true this value will be used when setting the opacity of the bar's fill.
@@ -144,6 +141,10 @@ If true this value will be used when setting the opacity of the bar's fill.
 How much padding to put around a bar.  A padding of 4 will result in 2 pixels
 on each side.
 
+=item stroke
+
+A stroke to use on each bar.
+
 =back
 
 =head1 METHODS
